translate.lang.ar

Package translate :: Package lang :: Module ar |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.ar

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007,2009,2011 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """This module represents Arabic language.
    23
    24  For more information, see U{http://en.wikipedia.org/wiki/Arabic_language}
    25  """
    26
    27  import re
    28
    29  from translate.lang import common
    30
    31 -def reverse_quotes(text):
    32      def convertquotation(match):
    33          return u"”%s“" % match.group(1)
    34      return re.sub(u'“([^”]+)”', convertquotation, text)
    35
    36
    37 -class ar(common.Common):
    38      """This class represents Arabic."""
    39
    40      listseperator = u"، "
    41
    42      puncdict = {
    43          u",": u"،",
    44          u";": u"؛",
    45          u"?": u"؟",
    46          #This causes problems with variables, so commented out for now:
    47          #u"%": u"٪",
    48      }
    49
    50      ignoretests = ["startcaps", "simplecaps", "acronyms"]
    51
    52 -    def punctranslate(cls, text):
    53          text = super(cls, cls).punctranslate(text)
    54          return reverse_quotes(text)
    55      punctranslate = classmethod(punctranslate)
    56